/**
 *  qdnet.h by Tyler Montbriand, 2004
 *  Free software as in free beer.  Do whatever you want with it.
 */

#ifndef __QDNET_H__
#define __QDNET_H__

#ifndef __cplusplus
#error "qdnet.h needs C++ compilation"
#endif

#include <SDL/SDL_net.h>
#include "qdsdl.h"

/**
 * A quick-n-dirty extension of the qdsdl class, to add SDL_net 
 * initialization.  SDL, then SDL_net will be initialized if possible
 * when this object goes into scope, and quit when it goes out of scope.
 * I'm unsure whether SDLNet_Init functionality is nestable, so be 
 * careful to use only one instance of this object.
 *
 * Example:
 *  #include <stdio.h>
 *  #include "qdnet.h"
 *
 *  int main(int argc, char *argv[])
 *  {
 *    qdnet net;
 *    if(!net.Good())
 *      return(1);
 *
 *    fprintf(stderr,"SDL and SDL_net initialized\n");
 *    return(0);
 *  }
 */
class qdnet:public qdsdl
{
public:
  qdnet(Uint32 flag=0):qdsdl(flag),good(false)
  {
    Init();
  }

  inline bool Init()
  {
    if(!qdsdl::Good())
      return(false);

    if(SDLNet_Init()<0)
    {
      fprintf(stderr,"Couldn't init SDL_Net: %s\n",SDLNet_GetError());
      return false;
    }

    good=true;
    return(true);
  }

  inline void Quit()
  {
    if(!good)
      return;

    good=false;
    SDLNet_Quit();
  }

  ~qdnet()
  {
    if(!good)
      return;

    SDLNet_Quit();
    good=false;
  }

  inline bool Good() { return good; }
private:
  bool good;
};

#endif/*__QDNET_H__*/
