/**
 *  qdwrap.h by Tyler Montbriand, 2004
 *  Free software as in free beer.  Do whatever you want with it..
 */
/********************************************************************
    In making wrapper classes for sockets, mutexes, and semaphores, I
  noticed I was writing a lot of the same code over and over again.
  This inline wrapper class incorporates the core functionality of
  nearly any class that wraps a pointer, and is no larger in code
  or memory footprint than the pointer it is wrapping.
    In anything that descends from it, be sure to set val to NULL
  after deleting/freeing it.  This way, qdwrap's base destructor will be 
  able to warn you if that somehow doesn't happen.
 ********************************************************************/
#ifndef __QDWRAP_H__
#define __QDWRAP_H__

#ifndef __cplusplus
#error "qdwrap.h needs c++ compilation"
#endif

// Quick and dirty wrapper class for nearly anything pointerish
template<class T>
class qdwrap
{
public:
    // Constructor that sets it to the passed value
  inline qdwrap(T *valin=NULL):val(valin) {                    }
    // Operator to convert it to the pointer it holds
  inline operator T *()                   { return(val);       }
    // Tests if value is actually SET to anything
  inline bool Good()                      { return(val!=NULL); }
    // Clears val without deallocating it
  inline void clear()                     { val=NULL;          }
    // Sets val to valin without deallocating val
  inline void operator=(T *valin)         { val=valin;         }
    // Warns if nothing higher-up freed the contained value
  inline ~qdwrap()
  {
    if(val!=NULL)
      fprintf(stderr,"Warning!  Value not NULL\n");
  }
protected:
  T *val;
};

#endif/*__QDWRAP_H__*/
